@@ -29,18 +29,19 @@ class Converter(object):
         self.cleanup = cleanup
         self.verbose = verbose
 
-    def convert(self, format, output_filename=None):
+    def convert(self, format, output_filename=None, **options):
+        """ 'options' is passwd down html2fo() """
 
         if format == 'fo':
             if self.fo_filename is None:
-                self.fo_filename = HTML2FOConverter().convert(self.filename, self.encoding)
+                self.fo_filename = HTML2FOConverter().convert(self.filename, self.encoding, **options)
             return self.fo_filename
 
         if not format in supported_formats:
             raise ValueError('Unsupported format: %s' % format)
 
         if self.fo_filename is None:
-            self.fo_filename = HTML2FOConverter().convert(self.filename, self.encoding)
+            self.fo_filename = HTML2FOConverter().convert(self.filename, self.encoding, **options)
 
         if format == 'pdf':
             if not xinc_available:
