@@ -17,11 +17,11 @@ fop_home = os.environ.get('FOP_HOME')
 
 def _check_fop():
     if not fop_home:
-        LOG.error('$FOP_HOME not set')
+        LOG.debug('$FOP_HOME not set')
         return False
 
     if not os.path.exists(fop_home):
-        LOG.error('$FOP_HOME=%s does not exist' % fop_home)
+        LOG.debug('$FOP_HOME=%s does not exist' % fop_home)
         return False
 
     return True
