@@ -18,11 +18,11 @@ xfc_dir = os.environ.get('XFC_DIR')
 def _check_xfc():
 
     if not xfc_dir:
-        LOG.error('$XFC_DIR not set')
+        LOG.debug('$XFC_DIR not set')
         return False
 
     if not os.path.exists(xfc_dir):
-        LOG.error('$XFC=%s does not exist' % xfc_dir)
+        LOG.debug('$XFC=%s does not exist' % xfc_dir)
         return False
 
     return True
